import { Component, Input } from "@angular/core";
import { FeedbackService } from "./feedback.service";
import { FeedbackModel } from "./feedback.model";
var FeedbackModalComponent = (function () {
    function FeedbackModalComponent(feedback) {
        this.feedback = feedback;
        feedback.modalComponent = this;
    }
    /**
     * Cancel the feedback.
     */
    FeedbackModalComponent.prototype.cancel = function () {
        /* Callback on cancel.*/
        if (this.configuration.onCancel) {
            this.configuration.onCancel();
        }
        this.closeModal();
    };
    /**
     * Close this modal.
     */
    FeedbackModalComponent.prototype.closeModal = function () {
        this.isOpened = false;
        this.feedback.showSendFeedbackButton();
    };
    /**
     * Hide this modal.
     */
    FeedbackModalComponent.prototype.hideModal = function () {
        this.isOpened = false;
    };
    /**
     * Open feedback modal.
     */
    FeedbackModalComponent.prototype.openModal = function () {
        this.isOpened = true;
    };
    /**
     * Show this modal.
     */
    FeedbackModalComponent.prototype.showModal = function () {
        this.isOpened = true;
    };
    /**
     * Submit the form.
     * @param form the form.
     */
    FeedbackModalComponent.prototype.submit = function (form) {
        var feedbackSubmission = new FeedbackModel();
        feedbackSubmission.form = form;
        feedbackSubmission.screenshots = this.feedback.getScreenshots();
        /* Callback on submit validation */
        if (this.configuration.onSubmitValidation) {
            if (!this.configuration.onSubmitValidation(feedbackSubmission)) {
                return; // Do not proceed if validation unsuccessful.
            }
        }
        /* Callback on submit. */
        if (this.configuration.onSubmit) {
            this.configuration.onSubmit(feedbackSubmission);
            this.closeModal();
        }
        else {
            console.warn("No onSubmit callback function configured. It probably should.");
        }
    };
    return FeedbackModalComponent;
}());
export { FeedbackModalComponent };
FeedbackModalComponent.decorators = [
    { type: Component, args: [{
                selector: "ngx-bootstrap-feedback-modal",
                template: "<!--\n<modal title=\"{{configuration.feedbackModalTitle ? configuration.feedbackModalTitle : 'Send Feedback'}}\"\n        modalClass=\"{{configuration.feedbackModalClass ? configuration.feedbackModalClass : 'modal-md'}}\"\n        [hideCloseButton]=\"true\"\n        [closeOnEscape]=\"false\"\n        [closeOnOutsideClick]=\"false\">\n  <modal-header></modal-header>\n  <modal-content>\n    <form novalidate #userFeedbackForm>\n      <ng-content></ng-content>\n    </form>\n  </modal-content>\n  <modal-footer>\n    <button [attr.class]=\"configuration.cancelFeedbackButtonClass ? configuration.cancelFeedbackButtonClass : 'btn btn-default'\" data-dismiss=\"modal\" type=\"button\" (click)=\"closeModal()\">\n      {{configuration.cancelFeedbackButtonText ? configuration.cancelFeedbackButtonText : \"Cancel\"}}\n    </button>\n    <button [attr.class]=\"configuration.submitFeedbackButtonClass ? configuration.submitFeedbackButtonClass : 'btn btn-primary'\" type=\"button\" (click)=\"submit(userFeedbackForm)\">\n      {{configuration.submitFeedbackButtonText ? configuration.submitFeedbackButtonText : \"Submit\"}}\n    </button>\n  </modal-footer>\n</modal>\n-->\n\n<div class=\"modal\"\n     tabindex=\"-1\"\n     role=\"dialog\"\n     [ngClass]=\"{ in: isOpened, fade: isOpened }\"\n     [ngStyle]=\"{ display: isOpened ? 'block' : 'none' }\">\n  <div [attr.class]=\"configuration.feedbackModalClass ? configuration.feedbackModalClass : 'modal-dialog modal-md'\">\n    <div class=\"modal-content\" tabindex=\"0\">\n      <div class=\"modal-header\">\n        <h4 class=\"modal-title\">{{configuration.feedbackModalTitle ? configuration.feedbackModalTitle : 'Send Feedback'}}</h4>\n      </div>\n      <div class=\"modal-body\">\n        <form novalidate #userFeedbackForm>\n          <ng-content></ng-content>\n        </form>\n      </div>\n      <div class=\"modal-footer\">\n        <button [attr.class]=\"configuration.cancelFeedbackButtonClass ? configuration.cancelFeedbackButtonClass : 'btn btn-default'\" data-dismiss=\"modal\" type=\"button\" (click)=\"cancel()\">\n          {{configuration.cancelFeedbackButtonText ? configuration.cancelFeedbackButtonText : \"Cancel\"}}\n        </button>\n        <button [attr.class]=\"configuration.submitFeedbackButtonClass ? configuration.submitFeedbackButtonClass : 'btn btn-primary'\" type=\"button\" (click)=\"submit(userFeedbackForm)\">\n          {{configuration.submitFeedbackButtonText ? configuration.submitFeedbackButtonText : \"Submit\"}}\n        </button>\n      </div>\n    </div>\n  </div>\n</div>"
            },] },
];
/** @nocollapse */
FeedbackModalComponent.ctorParameters = function () { return [
    { type: FeedbackService, },
]; };
FeedbackModalComponent.propDecorators = {
    'configuration': [{ type: Input },],
};
//# sourceMappingURL=feedback-modal.component.js.map